@@ -1,7 +1,8 @@
 from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
 
+
 class CatClient(NamespacedClient):
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "v")
     def aliases(self, name=None, params=None):
         """
 
@@ -19,11 +20,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'aliases', name), params=params)
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "aliases", name), params=params
+        )
 
-    @query_params('bytes', 'format', 'h', 'help', 'local', 'master_timeout',
-        's', 'v')
+    @query_params("bytes", "format", "h", "help", "local", "master_timeout", "s", "v")
     def allocation(self, node_id=None, params=None):
         """
         Allocation provides a snapshot of how shards have located around the
@@ -45,10 +46,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'allocation', node_id), params=params)
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "allocation", node_id), params=params
+        )
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "v")
     def count(self, index=None, params=None):
         """
         Count provides quick access to the document count of the entire cluster,
@@ -68,11 +70,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat', 'count',
-            index), params=params)
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "count", index), params=params
+        )
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'ts',
-        'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "ts", "v")
     def health(self, params=None):
         """
         health is a terse, one-line representation of the same information from
@@ -91,10 +93,9 @@ class CatClient(NamespacedClient):
         :arg ts: Set to false to disable timestamping, default True
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', '/_cat/health',
-            params=params)
+        return self.transport.perform_request("GET", "/_cat/health", params=params)
 
-    @query_params('help', 's')
+    @query_params("help", "s")
     def help(self, params=None):
         """
         A simple help for the cat api.
@@ -104,10 +105,21 @@ class CatClient(NamespacedClient):
         :arg s: Comma-separated list of column names or column aliases to sort
             by
         """
-        return self.transport.perform_request('GET', '/_cat', params=params)
+        return self.transport.perform_request("GET", "/_cat", params=params)
 
-    @query_params('bytes', 'format', 'h', 'health', 'help', 'local',
-        'master_timeout', 'pri', 's', 'v')
+    @query_params(
+        "bytes",
+        "size",
+        "format",
+        "h",
+        "health",
+        "help",
+        "local",
+        "master_timeout",
+        "pri",
+        "s",
+        "v",
+    )
     def indices(self, index=None, params=None):
         """
         The indices command provides a cross-section of each index.
@@ -133,10 +145,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'indices', index), params=params)
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "indices", index), params=params
+        )
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "v")
     def master(self, params=None):
         """
         Displays the master's node ID, bound IP address, and node name.
@@ -153,11 +166,9 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', '/_cat/master',
-            params=params)
+        return self.transport.perform_request("GET", "/_cat/master", params=params)
 
-    @query_params('format', 'full_id', 'h', 'help', 'local', 'master_timeout',
-        's', 'v')
+    @query_params("format", "full_id", "h", "help", "local", "master_timeout", "s", "v")
     def nodes(self, params=None):
         """
         The nodes command shows the cluster topology.
@@ -176,10 +187,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', '/_cat/nodes',
-            params=params)
+        return self.transport.perform_request("GET", "/_cat/nodes", params=params)
 
-    @query_params('bytes', 'format', 'h', 'help', 'master_timeout', 's', 'v')
+    @query_params(
+        "bytes", "time", "size", "format", "h", "help", "master_timeout", "s", "v"
+    )
     def recovery(self, index=None, params=None):
         """
         recovery is a view of shard replication.
@@ -198,10 +210,13 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'recovery', index), params=params)
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "recovery", index), params=params
+        )
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params(
+        "bytes", "size", "format", "h", "help", "local", "master_timeout", "s", "v"
+    )
     def shards(self, index=None, params=None):
         """
         The shards command is the detailed view of what nodes contain which shards.
@@ -209,6 +224,8 @@ class CatClient(NamespacedClient):
 
         :arg index: A comma-separated list of index names to limit the returned
             information
+        :arg bytes: The unit in which to display byte values, valid choices are:
+            'b', 'k', 'kb', 'm', 'mb', 'g', 'gb', 't', 'tb', 'p', 'pb'
         :arg format: a short version of the Accept header, e.g. json, yaml
         :arg h: Comma-separated list of column names to display
         :arg help: Return help information, default False
@@ -220,10 +237,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'shards', index), params=params)
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "shards", index), params=params
+        )
 
-    @query_params('format', 'h', 'help', 's', 'v')
+    @query_params("bytes", "size", "format", "h", "help", "s", "v")
     def segments(self, index=None, params=None):
         """
         The segments command is the detailed view of Lucene segments per index.
@@ -231,6 +249,8 @@ class CatClient(NamespacedClient):
 
         :arg index: A comma-separated list of index names to limit the returned
             information
+        :arg bytes: The unit in which to display byte values, valid choices are:
+            'b', 'k', 'kb', 'm', 'mb', 'g', 'gb', 't', 'tb', 'p', 'pb'
         :arg format: a short version of the Accept header, e.g. json, yaml
         :arg h: Comma-separated list of column names to display
         :arg help: Return help information, default False
@@ -238,10 +258,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'segments', index), params=params)
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "segments", index), params=params
+        )
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "v")
     def pending_tasks(self, params=None):
         """
         pending_tasks provides the same information as the
@@ -260,11 +281,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', '/_cat/pending_tasks',
-            params=params)
+        return self.transport.perform_request(
+            "GET", "/_cat/pending_tasks", params=params
+        )
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'size',
-        'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "size", "v")
     def thread_pool(self, thread_pool_patterns=None, params=None):
         """
         Get information about thread pools.
@@ -285,11 +306,13 @@ class CatClient(NamespacedClient):
             '', 'k', 'm', 'g', 't', 'p'
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'thread_pool', thread_pool_patterns), params=params)
+        return self.transport.perform_request(
+            "GET",
+            _make_path("_cat", "thread_pool", thread_pool_patterns),
+            params=params,
+        )
 
-    @query_params('bytes', 'format', 'h', 'help', 'local', 'master_timeout',
-        's', 'v')
+    @query_params("bytes", "format", "h", "help", "local", "master_timeout", "s", "v")
     def fielddata(self, fields=None, params=None):
         """
         Shows information about currently loaded fielddata on a per-node basis.
@@ -310,10 +333,11 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'fielddata', fields), params=params)
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "fielddata", fields), params=params
+        )
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "v")
     def plugins(self, params=None):
         """
 
@@ -330,10 +354,9 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', '/_cat/plugins',
-            params=params)
+        return self.transport.perform_request("GET", "/_cat/plugins", params=params)
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "v")
     def nodeattrs(self, params=None):
         """
 
@@ -350,10 +373,9 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', '/_cat/nodeattrs',
-            params=params)
+        return self.transport.perform_request("GET", "/_cat/nodeattrs", params=params)
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "v")
     def repositories(self, params=None):
         """
 
@@ -370,12 +392,14 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', '/_cat/repositories',
-            params=params)
+        return self.transport.perform_request(
+            "GET", "/_cat/repositories", params=params
+        )
 
-    @query_params('format', 'h', 'help', 'ignore_unavailable', 'master_timeout',
-        's', 'v')
-    def snapshots(self, repository=None, params=None):
+    @query_params(
+        "format", "h", "help", "ignore_unavailable", "master_timeout", "s", "v"
+    )
+    def snapshots(self, repository, params=None):
         """
 
         `<https://www.elastic.co/guide/en/elasticsearch/reference/current/cat-snapshots.html>`_
@@ -393,11 +417,24 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'snapshots', repository), params=params)
+        if repository in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for a required argument 'repository'.")
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "snapshots", repository), params=params
+        )
 
-    @query_params('actions', 'detailed', 'format', 'h', 'help', 'node_id',
-        'parent_node', 'parent_task', 's', 'v')
+    @query_params(
+        "actions",
+        "detailed",
+        "format",
+        "h",
+        "help",
+        "nodes",
+        "node_id",
+        "parent_task_id",
+        "s",
+        "v",
+    )
     def tasks(self, params=None):
         """
 
@@ -409,21 +446,23 @@ class CatClient(NamespacedClient):
         :arg format: a short version of the Accept header, e.g. json, yaml
         :arg h: Comma-separated list of column names to display
         :arg help: Return help information, default False
+        :arg nodes: A comma-separated list of node IDs or names to limit the
+            returned information; use `_local` to return information from the
+            node you're connecting to, leave empty to get information from all
+            nodes (used for older version of Elasticsearch)
         :arg node_id: A comma-separated list of node IDs or names to limit the
             returned information; use `_local` to return information from the
             node you're connecting to, leave empty to get information from all
             nodes
-        :arg parent_node: Return tasks with specified parent node.
-        :arg parent_task: Return tasks with specified parent task id. Set to -1
+        :arg parent_task_id: Return tasks with specified parent task id. Set to -1
             to return all.
         :arg s: Comma-separated list of column names or column aliases to sort
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', '/_cat/tasks',
-            params=params)
+        return self.transport.perform_request("GET", "/_cat/tasks", params=params)
 
-    @query_params('format', 'h', 'help', 'local', 'master_timeout', 's', 'v')
+    @query_params("format", "h", "help", "local", "master_timeout", "s", "v")
     def templates(self, name=None, params=None):
         """
         `<https://www.elastic.co/guide/en/elasticsearch/reference/current/cat-templates.html>`_
@@ -440,6 +479,6 @@ class CatClient(NamespacedClient):
             by
         :arg v: Verbose mode. Display column headers, default False
         """
-        return self.transport.perform_request('GET', _make_path('_cat',
-            'templates', name), params=params)
-
+        return self.transport.perform_request(
+            "GET", _make_path("_cat", "templates", name), params=params
+        )
