@@ -6,6 +6,13 @@ from .base import Connection
 
 
 class PoolingConnection(Connection):
+    """
+    Base connection class for connections that use libraries without thread
+    safety and no capacity for connection pooling. To use this just implement a
+    ``_make_connection`` method that constructs a new connection and returns
+    it.
+    """
+
     def __init__(self, *args, **kwargs):
         self._free_connections = queue.Queue()
         super(PoolingConnection, self).__init__(*args, **kwargs)
@@ -18,3 +25,9 @@ class PoolingConnection(Connection):
 
     def _release_connection(self, con):
         self._free_connections.put(con)
+
+    def close(self):
+        """
+        Explicitly close connection
+        """
+        pass
