@@ -1,7 +1,11 @@
-from elasticsearch.helpers.test import get_test_client, ElasticsearchTestCase as BaseTestCase
+from elasticsearch.helpers.test import (
+    get_test_client,
+    ElasticsearchTestCase as BaseTestCase,
+)
 
 client = None
 
+
 def get_client(**kwargs):
     global client
     if client is not None and not kwargs:
@@ -10,6 +14,7 @@ def get_client(**kwargs):
     # try and locate manual override in the local environment
     try:
         from test_elasticsearch.local import get_client as local_get_client
+
         new_client = local_get_client(**kwargs)
     except ImportError:
         # fallback to using vanilla client
@@ -24,6 +29,7 @@ def get_client(**kwargs):
 def setup():
     get_client()
 
+
 class ElasticsearchTestCase(BaseTestCase):
     @staticmethod
     def _get_client(**kwargs):
